@@ -181,7 +181,7 @@
     <message>
         <location filename="mainwindow.cpp" line="262"/>
         <source>Version: </source>
-        <translation>גרסה:</translation>
+        <translation>גירסה:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="264"/>
