@@ -9,7 +9,7 @@
     <message>
         <location filename="mainwindow.ui" line="27"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Instalador de Codecs (Codecs Installer) é um aplicativo que possibilita a instalação de codecs não-livres (restritos) que permitem funções avançadas de vídeo e áudio.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Em alguns países, a distribuição dos mesmos podem estar limitada por lei, o usuário deve obedecer à legislação local. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Você assume a responsabilidade legal por baixar estes codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Instalador de Codecs (Codecs Installer) é um aplicativo que possibilita a instalação de codecs não livres (restritos) que permitem funções avançadas de vídeo e áudio.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;Em alguns países, a distribuição dos mesmos podem estar limitada por lei, o usuário deve obedecer à legislação local. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Você assume a responsabilidade legal por baixar estes codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="44"/>
