@@ -50,7 +50,7 @@
     <message>
         <location filename="mainwindow.ui" line="178"/>
         <source>About...</source>
-        <translation>O...</translation>
+        <translation>О программе...</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="185"/>
