@@ -146,7 +146,7 @@
     <message>
         <location filename="mainwindow.cpp" line="226"/>
         <source>Error running %1 command</source>
-        <translation type="unfinished"/>
+        <translation>Chyba pri behu %1 príkazu</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="238"/>
